/*
    Copyright 2020-2023. Huawei Technologies Co., Ltd. All rights reserved.

    Licensed under the Apache License, Version 2.0 (the "License")
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        https://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/

part of huawei_adsprime;

class AdvertisingIdClient {
  static Future<AdvertisingIdClientInfo> getAdvertisingIdInfo() async {
    final Map<dynamic, dynamic> args = await Ads.instance.channel.invokeMethod(
      'getAdvertisingIdInfo',
    );
    return AdvertisingIdClientInfo(
      args['advertisingId'],
      args['limitAdTrackingEnabled'],
    );
  }

  static Future<bool?> verifyAdId(
    String adId,
    bool limitTracking,
  ) {
    return Ads.instance.channel.invokeMethod(
      'verifyAdId',
      <String, dynamic>{
        'adId': adId,
        'limitTracking': limitTracking,
      },
    );
  }
}

class AdvertisingIdClientInfo {
  final String? _advertisingId;
  final bool? _limitAdTrackingEnabled;

  const AdvertisingIdClientInfo(
    this._advertisingId,
    this._limitAdTrackingEnabled,
  );

  String? get getId => _advertisingId;
  bool? get isLimitAdTrackingEnabled => _limitAdTrackingEnabled;
}
